#!/usr/bin/env python
# -*- coding: utf-8 -*-
# https://github.com/r3nt0n/bopscrk
# bopscrk - init script

#import sys, os, datetime

"""
Before Outset PaSsword CRacKing is a tool to assist in the previous process of cracking passwords.
"""

name = 'bopscrk.py'
__author__ = 'r3nt0n'
__version__ = '2.4.3'
__status__ = 'Development'


def start():
    try:
        from .modules import main
    # catching except when running python3 bopscrk.py (sketchy, need some refactor)
    except ImportError:
        from modules import main
    main.run(name, __version__)


if __name__ == '__main__':
    start()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# https://github.com/r3nt0n/bopscrk
# bopscrk - combinators functions module

import itertools

from . import Config
from .excluders import remove_duplicates


def add_common_separators(wordlist):
    words = wordlist[:]
    new_wordlist = []
    for word in words:
        for separator in Config.SEPARATORS_CHARSET:
            new_wordlist.append(word + separator)
            new_wordlist.append(separator + word)

    base_wordlist_with_seps = new_wordlist[:]

    for word in words:
        for wordseparated in base_wordlist_with_seps:
            if word not in wordseparated:
                new_wordlist.append(wordseparated + word)
                new_wordlist.append(word + wordseparated)

    return remove_duplicates(new_wordlist)


def combinator(wordlist, nWords):
    new_wordlist = wordlist[:]  # I need copy to use itertools properly
    wlist_combined = itertools.permutations(new_wordlist, nWords)
    for combination in wlist_combined:
        word = ''
        for i in combination:
            word += i
        if word not in new_wordlist: new_wordlist.append(word)

    return remove_duplicates(new_wordlist)

